#!/usr/bin/env python
#
# $Id: vidthumb.py,v 1.4 2003/12/22 11:30:45 stephen Exp $

"""Generate thumbnails for image files.  This must be called as
      magickthumb.py source_file destination_thumbnail maximum_size
where maximum_size is the maximum width and height.

This uses Imagemagick's convert to a PNG file, then gdk-pixbuf (via
pygtk 1.99.x) to generate a thumbnail of that frame.  A film strip effect is
added to mark the thumbnail as from a video file.

To use this in ROX-Filer, get a recent version then run MagickThumbnail and
click on "Install handlers".  """

import os, sys
import md5
import rox

import thumb

# Defaults
import options

outname=None
rsize=options.tsize.int_value
frameit=options.frameit.int_value

inner_bevel = rsize / 48
if inner_bevel < 2:
	inner_bevel = 2
outer_bevel = inner_bevel / 2
frame_width = inner_bevel + outer_bevel

print "scolor" , options.scolor.value
bcolor = options.scolor.value




debug=os.environ.get('MAGICKTHUMB_DEBUG', 0)

class MagickThumb(thumb.Thumbnailler):
    """Generate thumbnail for image files understood by ImageMagick"""
    def __init__(self, debug=False):
        """Initialize image thumbnailler"""
        thumb.Thumbnailler.__init__(self, 'MagickThumbnail', 'magickthumb',
                                    True, debug)
    def get_image(self, inname, rsize):
        """Convert image to PNG"""
        
        (fnamenoext, ext) = os.path.splitext(os.path.basename(inname))
	frfname = fnamenoext + '.png'	
	
	#cmd='convert -mattecolor %s -frame "%s"x"%s" -size "%s"x"%s" "%s" -resize "%s"x"%s" +profile "*" "%s"'  % (bcolor, bwidth, bwidth, rsize, rsize, inname, rsize, rsize, frfname)
	if frameit:
		cmd='convert -flatten -mattecolor "%s" -frame %sx%s+%s+%s -size %sx%s %s[0] -resize %sx%s +profile "*" %s'  % (bcolor, frame_width, frame_width, outer_bevel, inner_bevel, rsize, rsize, inname, rsize, rsize, frfname)
		#cmd='convert -mattecolor "#697B8F" -frame 6x6+2+4 -size %sx%s %s -resize %sx%s +profile "*" %s'  % (rsize, rsize, inname, rsize, rsize, frfname)
	else:
		cmd='convert -flatten -size %sx%s %s[0] -resize %sx%s +profile "*" %s'  % (rsize, rsize, inname, rsize, rsize, frfname)
        cmd+=' > /dev/null 2>&1'
	    
	os.system(cmd)
	try:
		os.stat(frfname)
	except:
		self.report_exception()
		sys.exit(2)
	
        # Now we load the raw image in
        gtk=rox.g

        return gtk.gdk.pixbuf_new_from_file(frfname)

    def process_image(self, img, rsize):
	return img
        
# Process command line args.  Although the filer always passes three args,
# let the last two default to something sensible to allow use outside
# the filer.
def main(argv):
    """Process command line args.  Although the filer always passes three args,
    let the last two default to something sensible to allow use outside
    the filer."""
    
    #print argv
    inname=argv[0]
    try:
        outname=argv[1]
    except:
        pass
    try:
        rsize=int(argv[2])
    except:
        pass
    
    if not os.path.isabs(inname):
        inname=os.path.abspath(inname)

    # Out file name is based on MD5 hash of the URI
    if not outname:
        uri='file://'+inname
        tmp=md5.new(uri).digest()
        leaf=''
        for c in tmp:
            leaf+='%02x' % ord(c)
        outname=os.path.join(os.environ['HOME'], '.thumbnails', 'normal',
                         leaf+'.png')
    elif not os.path.isabs(outname):
        outname=os.path.abspath(outname)
    #print inname, outname, rsize

    thumb= MagickThumb(int(debug))
    thumb.run(inname, outname, rsize)

def configure():
    """Configure the app"""
    options.edit_options()
    rox.mainloop()

if __name__=='__main__':
    main(sys.argv[1:])
